# Example directory

This directory contains usage examples of the chemfiles library, for the C and C++
languages. Similar examples can be found in the corresponding repository for
all the bindings to chemfiles.

All of these example are compiled with the latest release to ensure that they are
up-to-date.

The files `indexes.*` present an example of reading a single frame from a
trajectory, and doing some analysis on it.

The files `rmsd.*` present an example of reading multiple frames from a
trajectory, and doing some analysis on the trajectory of a particle.

The files `convert.*` present an example of setting frame properties, and then
writing these frames to a trajectory.
